    # Security Policy
   
    ## Supported Versions
   
    | Version | Supported          |
    | ------- | ------------------ |
    | 1.0.x   | :white_check_mark: |
    | < 1.0   | :x:                |
   
   ## Reporting a Vulnerability
  
   Please report security vulnerabilities by opening a [private security advisory](https://github.com/Cameron-Lyons/survival-rs/security/advisories/new) on GitHub.
  
   Include:
   - Description of the vulnerability
   - Steps to reproduce
   - Potential impact
   - Suggested fix (if any)
  
